@@ -26,7 +26,7 @@
 
 #include "song.h"
 #include "singinggame.h"
-#include "file_helper.h"
+#include "../file_helper.h"
 #include "chum.h"
 
 static ClutterActor* recording_cursor; //we want ask this location
@@ -355,9 +355,7 @@ static gboolean song_icon_clicked(TangleButton* tanglebutton, gpointer data){
 		jammo_sequencer_add_track(sequencer, JAMMO_TRACK(backing_track));
 		g_free(filename);
 
-		gchar* jammo_directory=configure_get_jammo_directory();
-		gchar* recording_filename = g_strdup_printf("%s/last_recorded.wav",jammo_directory);
-		g_free(jammo_directory);
+		gchar* recording_filename = g_strdup_printf("%s/last_recorded.wav",configure_get_jammo_directory());
 		JammoRecordingTrack* recording_track;
 
 
