@@ -170,7 +170,7 @@ static void create_samplebutton(gchar* themename, gchar* variation, gchar* image
 	gchar *full_image = g_strdup_printf("themes/%s/%s/%s",themename,variation,imagefile);
 	//printf("image file: '%s'\n",full_image);
 
-	gchar *full_sound = g_strdup_printf("themes/%s/%s/%s",themename,variation,soundfile);
+	gchar *full_sound = g_strdup_printf("%s/%s/%s/%s",THEMES_DIR,themename,variation,soundfile);
 	//printf("sound file: '%s'\n",full_sound);
 
 	ClutterActor* sample_button;
