@@ -12,6 +12,8 @@ This file contains the functionality of help menu.
 #include "community_utilities.h"
 #include "single_thread.h"
 #include "src/configure.h"
+#include <libintl.h>
+#include "../../cem/cem.h"
 
 static ClutterContainer *questionlist = 0;
 static gint listItemHeight = 0;
@@ -23,7 +25,8 @@ TextField addquestion_questionTextField;
 
 void start_helpdesk()
 {
-	puts("Starting Helpdesk\n");
+	cem_add_to_log(_("Starting Helpdesk"), J_LOG_DEBUG);
+	helpdesk_messages = 0;
 	helpdesk_get_questions();
 	helpdesk_show_helpdesk_view();
 }
@@ -31,51 +34,87 @@ void start_helpdesk()
 void helpdesk_goto_communitymenu(TangleButton *tanglebutton, gpointer none)
 {
 	clear_container(questionlist);
+	clear_messagelist(helpdesk_messages);
+	g_list_free(helpdesk_messages);
 	start_communitymenu();
 }
 
 void helpdesk_goto_startmenu(TangleButton *tanglebutton, gpointer none)
 {
 	clear_container(questionlist);
+	clear_messagelist(helpdesk_messages);
+	g_list_free(helpdesk_messages);
 	startmenu_goto_startmenu(tanglebutton, none);
 }
 
+void helpdesk_return_from_threads_view(GList *messagelist)
+{
+	helpdesk_messages = messagelist;
+	helpdesk_show_helpdesk_view();
+}
+
 gboolean helpdesk_mentor_clicked (TangleButton *tanglebutton, gpointer data)   
 {
-	printf("Mentor Clicked\n");
+	cem_add_to_log(_("Mentor Clicked"), J_LOG_DEBUG);
 	return TRUE;
 }
 
-void helpdesk_view_question(ClutterActor *actor)
+void helpdesk_get_questions(void)
 {
- 	helpdesk_find_selected_actor(actor);
-	helpdesk_show_question_view();
+	//TODO: Create code for fetching helpdesk questions from remote server
+	cem_add_to_log(_("Fetching Questions From Community Server"), J_LOG_DEBUG);
+}
+
+GList* helpdesk_get_number_of_questions(void)
+{
+	GList *temp = 0;
+
+	helpdesk_messages = g_list_first(helpdesk_messages);
+
+	int index = 0;
+
+	if(g_list_length(helpdesk_messages) != 0)
+	{
+		message *temp_msg = helpdesk_messages->data;
+
+		temp = g_list_append(temp, (gpointer)temp_msg);
+
+		while(helpdesk_messages->next != NULL)
+		{
+			helpdesk_messages = helpdesk_messages->next;
+
+			message *temp_msg = helpdesk_messages->data;
+
+			if(temp_msg->index > index) 
+			{
+				index = temp_msg->index;
+				temp = g_list_append(temp, (gpointer)temp_msg);
+			}
+		}
+		g_list_first(temp);
+		return temp;
+	}
+	else
+	return NULL;
 }
 
-/*****VIEW FUNCTIONS******/
 void helpdesk_show_helpdesk_view(void)
 {
-	helpdesk_messages = g_list_first(helpdesk_messages);
-	guint num_of_questions = g_list_length(helpdesk_messages);	//number of questions we have.
-	int i = 0;
+	GList *questions = helpdesk_get_number_of_questions();
 
-	printf("Founded %d Questions\n", num_of_questions);
+	int number_of_questions = g_list_length(questions);
+	int i = 0;
 
 	ClutterActor* mainview = jammo_get_actor_by_id("main-views-widget");
 	clutter_container_foreach(CLUTTER_CONTAINER(mainview), CLUTTER_CALLBACK(tangle_actor_hide_animated), NULL);
-
 	ClutterActor* help_view = jammo_get_actor_by_id("helpdesk-view");
 
 	if(help_view)
 	{
 		clutter_actor_show(CLUTTER_ACTOR(help_view));
+		clutter_actor_show(jammo_get_actor_by_id("helpdesk-no-questions-textfield"));
 
-		if(num_of_questions > 0)
-			clutter_actor_hide(jammo_get_actor_by_id("helpdesk-no-questions-textfield"));
-		else
-			clutter_actor_show(jammo_get_actor_by_id("helpdesk-no-questions-textfield"));
-
-		if(num_of_questions > 4)
+		if(number_of_questions > 4)
 		{
 			questionlist = CLUTTER_CONTAINER(jammo_get_actor_by_id("helpdesk-list-scrollable"));	
 			ClutterAction *listAction = tangle_actor_get_action_by_type(CLUTTER_ACTOR(questionlist), TANGLE_TYPE_SCROLL_ACTION);
@@ -83,40 +122,37 @@ void helpdesk_show_helpdesk_view(void)
 		}
 		else	questionlist = CLUTTER_CONTAINER(jammo_get_actor_by_id("helpdesk-list-unscrollable"));
 
-		if(num_of_questions != 0)
-		{				
-			do{	
-				message *previousmsg = helpdesk_messages->data;
-
-				if(i > 0)
-				helpdesk_messages = helpdesk_messages->next;
-
-				message *msg = helpdesk_messages->data;
-
-				if(i == 0)
-				helpdesk_add_loop_to_list(msg, msg->index, -1);
+		if(number_of_questions != 0)
+		{	
+			clutter_actor_hide(jammo_get_actor_by_id("helpdesk-no-questions-textfield"));
 			
-				else
-				helpdesk_add_loop_to_list(msg, msg->index, previousmsg->index);
+			do{	
+				if(i > 0)
+				questions = questions->next;
 
+				message *msg = questions->data;
+
+				helpdesk_add_question_to_list(msg, i);
 				i++;
-				
-			}while(helpdesk_messages->next != NULL);
+			}while(questions->next != NULL);
 		}
-	
 	}
+	else 	cem_add_to_log(_("Can't find 'helpdesk-view'"), J_LOG_DEBUG);
 
-	else 	puts("can't find 'helpdesk-view' ");
+	g_list_free(questions);
 }
 
-void helpdesk_show_question_view(void)
+void helpdesk_show_question_view(ClutterActor *actor)
 {
+ 	helpdesk_find_selected_actor(actor);
+
 	clear_container(questionlist);	
 
 	ClutterActor* mainview = jammo_get_actor_by_id("main-views-widget");
 	clutter_container_foreach(CLUTTER_CONTAINER(mainview), CLUTTER_CALLBACK(tangle_actor_hide_animated), NULL);
 
-	printf("Showing Question: %d\n", selectedQuestion);
+	///TRANSLATORS: Leave %d as is because it is needed
+	printf(_("Showing Question: %d"), selectedQuestion);
 
 	start_thread_view(helpdesk_messages, "helpdesk", NULL, selectedQuestion);
 
@@ -124,7 +160,7 @@ void helpdesk_show_question_view(void)
 
 void helpdesk_show_addquestion_view(void)
 {
-	puts("Starting AddQuestion View\n");
+	cem_add_to_log(_("Starting AddQuestion View"), J_LOG_DEBUG);
 
 	clear_container(questionlist);
 
@@ -137,8 +173,8 @@ void helpdesk_show_addquestion_view(void)
 	{
 		clutter_actor_show(CLUTTER_ACTOR(comment_view));
 
-		clutter_text_set_text(CLUTTER_TEXT(jammo_get_actor_by_id("helpdesk-addquestion-title")), "Add Your Topic Here");
-		clutter_text_set_text(CLUTTER_TEXT(jammo_get_actor_by_id("helpdesk-addquestion-description")), "Add Your Question Here");
+		clutter_text_set_text(CLUTTER_TEXT(jammo_get_actor_by_id("helpdesk-addquestion-title")), _("Add Your Topic Here"));
+		clutter_text_set_text(CLUTTER_TEXT(jammo_get_actor_by_id("helpdesk-addquestion-description")), _("Add Your Question Here"));
 
 		addquestion_titleTextField.text = jammo_get_actor_by_id("helpdesk-addquestion-title");
 		addquestion_titleTextField.lineCount = 3;
@@ -156,9 +192,28 @@ void helpdesk_show_addquestion_view(void)
 
 void helpdesk_add_question(void)
 {
-	puts("Adding Question");
+	cem_add_to_log(_("Adding Question"), J_LOG_DEBUG);
 
-	int index = g_list_length(helpdesk_messages);
+	int index = 0;
+
+	helpdesk_messages = g_list_first(helpdesk_messages);
+
+	if(g_list_length(helpdesk_messages) != 0)
+	{
+		while(helpdesk_messages->next != NULL)
+		{
+			helpdesk_messages = helpdesk_messages->next;
+
+			message *temp = helpdesk_messages->data;
+
+			if(temp->index > index)
+			index = temp->index;
+		}
+
+		index++;
+	}
+
+	//Next we add the message to helpdesk_messages list
 
 	message *msg = 0;
 	time_type now;
@@ -181,13 +236,6 @@ void helpdesk_add_question(void)
 	helpdesk_show_helpdesk_view();
 }
 
-void helpdesk_get_questions(void)
-{
-	//TODO: Create code for fetching helpdesk questions from remote server
-	puts("Fetching Questions From Community Server");
-	/*Initialize question array*/
-}
-
 void helpdesk_autoscroll_to_correct_pos(ClutterActor *listToScroll)
 {
 	gint slot;
@@ -203,88 +251,75 @@ void helpdesk_autoscroll_to_correct_pos(ClutterActor *listToScroll)
 	tangle_object_animate(G_OBJECT(action), CLUTTER_EASE_IN_OUT_QUAD, 300, "offset-y", (gfloat)(slot*listItemHeight), NULL);
 }
 
-gboolean helpdesk_add_loop_to_list(gpointer data, int index, int previousindex)
+gboolean helpdesk_add_question_to_list(gpointer data, int index)
 {	
-	if(previousindex != index)
-	{
-		message *msg = data;
-	
-		ClutterActor *colorbar = clutter_texture_new_from_file("/opt/jammo/communitymenu/colorbar13.png",NULL);
-		ClutterActor *avatarImage = clutter_texture_new_from_file("/opt/jammo/communitymenu/community_avatarbackground_small.png", NULL);
+	message *msg = data;
+	char topictitle[33];
 
-		char topictitle[33];
+	strncpy(topictitle, msg->title, 33);
+	topictitle[29] = topictitle[30] = topictitle[31] = '.'; 
+	topictitle[32] ='\0'; 
 
-		strncpy(topictitle, msg->title, 33);
-		topictitle[29] = topictitle[30] = topictitle[31] = '.'; 
-		topictitle[32] ='\0';    
+	ClutterActor *colorbar = clutter_texture_new_from_file("/opt/jammo/communitymenu/colorbar13.png",NULL);
+	ClutterActor *avatarImage = clutter_texture_new_from_file("/opt/jammo/communitymenu/community_avatarbackground_small.png", NULL);
 
-		ClutterActor *text = clutter_text_new_with_text("Comic Sans 20", topictitle);	
-		ClutterActor *questionButton = tangle_button_new_with_background_actor(text);
+	ClutterActor *text = clutter_text_new_with_text("Comic Sans 20", topictitle);	
+	ClutterActor *questionButton = tangle_button_new_with_background_actor(text);
 
-		ClutterActor *commentButton = tangle_button_new_with_background_actor(clutter_texture_new_from_file(
-						"communitymenu/community_comment_icon.png", NULL));
-		ClutterContainer *listContainer = CLUTTER_CONTAINER(clutter_group_new());
+	ClutterActor *commentButton = tangle_button_new_with_background_actor(clutter_texture_new_from_file(
+					"communitymenu/community_comment_icon.png", NULL));
 
-		if(avatarImage == NULL || colorbar == NULL || commentButton == NULL)
-		{	
-			printf("NULL Pointer Detected!\n");
-			return FALSE;	
-		}
+	ClutterContainer *listContainer = CLUTTER_CONTAINER(clutter_group_new());
 
-		if(listItemHeight == 0) listItemHeight = clutter_actor_get_height(avatarImage) + 1;
-
-		clutter_actor_set_position(colorbar, 0, listItemHeight - 1);
-		clutter_container_add_actor(listContainer, colorbar);		//Add components inside the container
-		clutter_container_add_actor(listContainer, avatarImage);
-	
-		clutter_actor_set_position(questionButton, 60, 23);			
-		clutter_container_add_actor(listContainer, questionButton);
-	
-		clutter_actor_set_position(commentButton, 690, 15);
-		clutter_container_add_actor(listContainer, commentButton);
-
-		g_signal_connect_swapped(CLUTTER_ACTOR(questionButton), "clicked", G_CALLBACK(helpdesk_view_question), 
-							clutter_actor_get_parent(questionButton));
-
-		g_signal_connect_swapped(CLUTTER_ACTOR(commentButton), "clicked", G_CALLBACK(helpdesk_view_question), 
-							clutter_actor_get_parent(commentButton));
-
-		clutter_container_add_actor(questionlist, CLUTTER_ACTOR(listContainer));
-
-		if(index <= 5)
-			clutter_actor_set_height(CLUTTER_ACTOR(questionlist), listItemHeight * (index+1));	
-
-		else
-			clutter_actor_set_height(CLUTTER_ACTOR(questionlist), listItemHeight * 6);		
-
-		return TRUE;
+	if(avatarImage == NULL || colorbar == NULL || commentButton == NULL)
+	{	
+		printf(_("NULL Pointer Detected!\n"));
+		return FALSE;	
 	}
-	else
-		return FALSE;
-}
 
-void helpdesk_return_from_threads_view(GList *messagelist)
-{
-	helpdesk_messages = messagelist;
-	helpdesk_show_helpdesk_view();
+	if(listItemHeight == 0) listItemHeight = clutter_actor_get_height(avatarImage) + 1;
+
+	clutter_actor_set_position(colorbar, 0, listItemHeight - 1);
+	clutter_container_add_actor(listContainer, colorbar);		//Add components inside the container
+	clutter_container_add_actor(listContainer, avatarImage);
+
+	clutter_actor_set_position(questionButton, 60, 23);			
+	clutter_container_add_actor(listContainer, questionButton);
+
+	clutter_actor_set_position(commentButton, 690, 15);
+	clutter_container_add_actor(listContainer, commentButton);
+
+	g_signal_connect_swapped(CLUTTER_ACTOR(questionButton), "clicked", G_CALLBACK(helpdesk_show_question_view), 
+						clutter_actor_get_parent(questionButton));
+
+	g_signal_connect_swapped(CLUTTER_ACTOR(commentButton), "clicked", G_CALLBACK(helpdesk_show_question_view), 
+						clutter_actor_get_parent(commentButton));
+
+	clutter_container_add_actor(questionlist, CLUTTER_ACTOR(listContainer));
+
+	if(index <= 5)
+		clutter_actor_set_height(CLUTTER_ACTOR(questionlist), listItemHeight * (index+1));	
+	else
+		clutter_actor_set_height(CLUTTER_ACTOR(questionlist), listItemHeight * 5);		
+
+	return TRUE;
 }
 
 void helpdesk_find_selected_actor(ClutterActor *actor)
 {
 	GList *children = clutter_container_get_children(questionlist); //Get list of actors
-	GList *node = children;
 
 	int index = 0;
 	
-	while(node != NULL)
+	while(children != NULL)
 	{
-		if(actor == node->data)
+		if(actor == children->data)
 		{
 			selectedQuestion = index;
 			break;
 		}
 
-		node = node->next;
+		children = children->next;
 
 		index++;
 	}
