@@ -13,38 +13,23 @@ This file contains the functionality of Help menu.
 #define MAX_COMMENTS 15
 
 void start_helpdesk();
-void helpdesk_get_questions(void);
-
 void helpdesk_goto_communitymenu(TangleButton *tanglebutton, gpointer none);
 void helpdesk_goto_startmenu(TangleButton *tanglebutton, gpointer none);
 
+void helpdesk_get_questions(void);
+GList* helpdesk_get_number_of_questions(void);
+
 //Functions for creating and moving loops
-gboolean helpdesk_add_loop_to_list(gpointer data, int index, int previousindex);
+gboolean helpdesk_add_question_to_list(gpointer data, int index);
 void helpdesk_autoscroll_to_correct_pos(ClutterActor *listToScroll);
 void helpdesk_find_selected_actor(ClutterActor *actor);
 
 //Signal functions
 void helpdesk_add_question(void);
-void helpdesk_view_question(ClutterActor *actor);
 
-void helpdesk_show_question_view(void);
+void helpdesk_show_question_view(ClutterActor *actor);
 void helpdesk_show_helpdesk_view(void);
 void helpdesk_show_addquestion_view(void);
 
 void helpdesk_return_from_threads_view(GList *messagelist);
-
-typedef struct {
-	char sender[20];
-	char answer[150];
-}comment_type;
-
-typedef struct {
-	char sender[20];
-	char title[100];
-	char desc[300];
-	comment_type comments[MAX_COMMENTS];
-}helpdesk_question_type;
-	
-
-
 #endif 
