@@ -41,6 +41,8 @@ View contains three part:
 #include "../../configure.h"
 #include "../file_helper.h"
 
+#include "mysongs.h"
+
 
 /*
 Sequencer and sequencer-track-view-area are defined in json.
@@ -455,7 +457,7 @@ void fullsequencer_home_clicked (TangleButton* tanglebutton, gpointer none){
 	//Confirmation?
 
 	tangle_view_unload(TANGLE_VIEW(current_levelview));
-	current_levelview==NULL;
+	current_levelview=NULL;
 	startmenu_goto_startmenu(NULL,NULL);
 }
 
@@ -555,6 +557,11 @@ void sequencer_save_project_button_pressed (TangleButton* tanglebutton, gpointer
 }
 
 
+void sequencer_mysongs_button_pressed (TangleButton* tanglebutton, gpointer none){
+	start_mysongs();
+}
+
+
 void fullsequencer_metronome_clicked (TangleButton* tanglebutton, gpointer none){
 	cem_add_to_log("Metronome pressed",J_LOG_USER_ACTION);
 
