@@ -23,36 +23,20 @@ void startmenu_goto_sequencer (TangleButton* tanglebutton, gpointer none){
 }
 
 void startmenu_goto_gamesmenu (TangleButton* tanglebutton, gpointer none){
-	printf("startmenu_goto_gamesmenu\n");
+	cem_add_to_log("From startmenu to gamesmenu clicked",J_LOG_USER_ACTION);
 	start_gamesmenu();
 }
 
 void startmenu_goto_communitymenu(TangleButton* tanglebutton, gpointer none){
-	printf("startmenu_goto_communitymenu\n");
+	cem_add_to_log("From startmenu to communitymenu clicked",J_LOG_USER_ACTION);
 	start_communitymenu();
 
 }
 
 void startmenu_mentor_clicked(TangleButton* tanglebutton, gpointer none){
-	printf("startmenu_mentor_clicked\n");
+	cem_add_to_log("On startmenu mentor clicked",J_LOG_USER_ACTION);
 }
 
-void startmenu_left_arrow_clicked(TangleButton* tanglebutton, gpointer none){
-	printf("startmenu_left_arrow_clicked\n");
-	ClutterActor* scroller = jammo_get_actor_by_id( "startmenu-scroller");
-	float old_value;
-	g_object_get(scroller, "scrolling-offset-x", &old_value, NULL);
-	clutter_actor_animate(scroller, CLUTTER_EASE_IN_OUT_QUAD, 250,"scrolling-offset-x",old_value+250, NULL);
-}
-void startmenu_right_arrow_clicked(TangleButton* tanglebutton, gpointer none){
-	printf("startmenu_right_arrow_clicked\n");
-	ClutterActor* scroller = jammo_get_actor_by_id( "startmenu-scroller");
-	float old_value;
-	g_object_get(scroller, "scrolling-offset-x", &old_value, NULL);
-	clutter_actor_animate(scroller, CLUTTER_EASE_IN_OUT_QUAD, 250,"scrolling-offset-x",old_value-250, NULL);
-}
-
-
 void startmenu_draw_version_information(TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
 
 	//Show version number: defined in configure.ac
