@@ -43,7 +43,13 @@
 //#include "singinggame.h"
 
 #include <libintl.h> //For gettext
-
+#ifdef DEBUG
+/*If compiled without optimization (-O0), setlocale is not found, because locale.h is not then included
+ see more: http://blog.flameeyes.eu/2008/09/02/testing-the-corner-cases
+ This might be fixed on newer libintl.h
+*/
+#include <locale.h>
+#endif
 
 #ifdef N900
 #include <libosso.h>
