@@ -166,23 +166,51 @@ guint32 ProfileManager::GetId()
 
 gboolean ProfileManager::loadEncryptedProfile(gchar* _username)
 {
-	return iStorageAgent->loadEncryptedProfile(_username);
+	if(iStorageAgent->isProfileLoaded()) return TRUE; // TODO check if user is the same as previously loaded!
+	
+	switch(iStorageAgent->readProfile(_username))
+	{
+		case 0:
+			return TRUE;
+		case 1:
+		case 2:
+		default:
+			return FALSE;
+	}
 }
 
 gboolean ProfileManager::saveEncryptedProfile()
 {
 	string param = string(PROF_PARAM_USERNAME);
 	gchar* username = (gchar*)ViewDetail(param).c_str();
-	if(iStorageAgent->saveEncryptedProfile(username))
-	{
-		iSavingRequired = FALSE;
-		return TRUE;
-	}
-	else
-	{
-		iSavingRequired = TRUE;
-		return FALSE;
-	}
+
+	if(username == NULL) return FALSE;
+	
+		switch(iStorageAgent->writeProfile(username))
+		{
+			// Errors accessing file
+			case -1:
+				iSavingRequired = TRUE;
+				return FALSE;
+			// OK
+			case 0:
+				iSavingRequired = FALSE;
+				return TRUE;
+			
+			// Salt missing
+			case 2:
+			// Password hash missing
+			case 3:
+			// Profile hash missing
+			case 4:
+			// encrypted profile missing
+			case 5:
+			// encrypted profile size missing
+			case 6:
+			default:
+				iSavingRequired = TRUE;
+				return FALSE;
+		}
 }
 
 gboolean ProfileManager::changeLoadedUser(gchar* _username)
