@@ -188,6 +188,9 @@ guint16 profilemanager_get_age(ProfileManager* _aManager);
 /* Get points */
 guint32 profilemanager_get_points(ProfileManager* _aManager);
 
+/* Get avatar id */
+guint32 profilemanager_get_avatarid(ProfileManager* _aManager);
+
 /* Set own username */
 gboolean profilemanager_set_username(ProfileManager* _aManager, gchar* _value);
 
@@ -200,6 +203,9 @@ gboolean profilemanager_set_lastname(ProfileManager* _aManager, gchar* _value);
 /* Set age - limit is 120 */
 gboolean profilemanager_set_age(ProfileManager* _aManager, guint16 _value);
 
+/* Get avatar id */
+gboolean profilemanager_set_avatarid(ProfileManager* _aManager, guint32 _value);
+
 /* Add points */
 gboolean profilemanager_add_points(ProfileManager* _aManager, guint32 _value);
 
