@@ -331,55 +331,11 @@ gboolean StorageAgent::setAuthenticated()
 	return TRUE;
 }
 
-gboolean StorageAgent::loadEncryptedProfile(gchar* username)
+gboolean StorageAgent::isProfileLoaded()
 {
-	if(username == NULL) return FALSE;
-	
-	// Profile was succesfully loaded before
-	if(profileloaded) return TRUE; // TODO check if user is the same as previously loaded!
-	
-	switch(readProfile(username))
-	{
-		case 0:
-			profileloaded = TRUE;
-			return TRUE;
-		case 1:
-		case 2:
-		case 3:
-		default:
-			return FALSE;
-	}
+	return profileloaded;
 }
 
-gboolean StorageAgent::saveEncryptedProfile(gchar* username)
-{
-	if(username == NULL) return FALSE;
-	
-	switch(writeProfile(username))
-	{
-		// Errors accessing file
-		case -1:
-			return FALSE;
-		// OK
-		case 0:
-			return TRUE;
-			
-		// TODO get missing values from ?
-		// Salt missing
-		case 2:
-		// Password hash missing
-		case 3:
-		// Profile hash missing
-		case 4:
-		// encrypted profile missing
-		case 5:
-		// encrypted profile size missing
-		case 6:
-		default:
-			return FALSE;
-	}
-	
-}
 
 gboolean StorageAgent::deserializeProfile(gchar* profile)
 {
@@ -591,6 +547,8 @@ gint StorageAgent::readProfile(gchar* username)
 			
 			// Profile length
 			//*enc_length = e_len;
+
+			profileloaded = TRUE;
 		}
 	}
 	else
