@@ -55,9 +55,7 @@ public:
 	
 	gboolean isAuthenticated();
 	gboolean setAuthenticated();
-	
-	gboolean loadEncryptedProfile(gchar* username);
-	gboolean saveEncryptedProfile(gchar* username);
+	gboolean isProfileLoaded();
 	
 	gboolean deserializeProfile(gchar* profile);
 	gchar* serializeProfile();
@@ -73,11 +71,13 @@ public:
 	gboolean setEncryptedProfile(guchar* _profile_hash, guchar* _encrypted_profile, guint _e_profile_size);
 	
 	void clearEncryptedData();
+
+	gint readProfile(gchar* username);
+	gint writeProfile(gchar* username);
 	
 private:
 	
-	gint readProfile(gchar* username);
-	gint writeProfile(gchar* username);
+	
 	// The map is for storing key-value pairs of user
 	// profile info and an iterator for going through the data
 	map<string, string> profileDetails;
