@@ -21,6 +21,7 @@
 #include "gems_profile_manager.h"
 #include "gems_service_collaboration.h"
 #include "gems_service_control.h"
+#include "gems_service_mentor.h"
 
 
 void jammo_gems_init(int argc, char* argv[]);
@@ -47,6 +48,7 @@ gems_service_profile* gems_get_service_profile();
 gems_service_group* gems_get_service_group();
 gems_service_collaboration* gems_get_service_collaboration();
 gems_service_control* gems_get_service_control();
+gems_service_mentor* gems_get_service_mentor();
 gems_teacher_connection* gems_get_teacher_connection();
 gboolean gems_teacher_connection_is_connected();
 
