@@ -552,6 +552,71 @@ gems_message* gems_create_message_group_management_group_info(gint16 type)
 	return msg;
 }
 
+gems_message* gems_create_message_group_management_group_info_teacher(gint16 type, gems_group_info* groupinfo)
+{
+	gems_message* msg = (gems_message*)g_malloc(sizeof(gems_message));
+	guint position = 0;
+	
+	// service id + packet length + command id + group id
+	msg->length = sizeof(gint16) + sizeof(gint32) + sizeof(gint16) + sizeof(guint32);
+
+	// owner + type + size + spaces + theme + member + member + member
+	msg->length = msg->length + sizeof(guint32) + sizeof(gint16) + sizeof(gint16) + sizeof(gint16) + sizeof(gint16) + sizeof(guint32) + sizeof(guint32) + sizeof(guint32);
+	
+
+	msg->message = (gchar*)g_malloc(sizeof(gchar*) * msg->length);
+	
+	// Service id 16 bits
+	*(gint16*)&msg->message[position] = g_htons(GROUP_SERVICE_ID);
+	position = position + sizeof(gint16);
+	
+	// Length 32 bits
+	*(gint32*)&msg->message[position] = g_htonl(msg->length);
+	position = position + sizeof(gint32);
+	
+	// Command 16 bits
+	*(gint16*)&msg->message[position] = g_htons(type);
+	position = position + sizeof(gint16);
+	
+	// Group id 32 bits
+	*(guint32*)&msg->message[position] = g_htonl(groupinfo->id);
+	position = position + sizeof(guint32);
+
+	// owner
+	*(guint32*)&msg->message[position] = g_htonl(groupinfo->owner);
+	position = position + sizeof(guint32);
+			
+	// type
+	*(gint16*)&msg->message[position] = g_htons(groupinfo->type);
+	position = position + sizeof(gint16);
+			
+	// size
+	*(gint16*)&msg->message[position] = g_htons(groupinfo->size);
+	position = position + sizeof(gint16);
+			
+	// spaces
+	*(gint16*)&msg->message[position] = g_htons(gems_group_get_spaces(groupinfo));
+	position = position + sizeof(gint16);
+			
+	// theme
+	*(gint16*)&msg->message[position] = g_htons(groupinfo->theme);
+	position = position + sizeof(gint16);
+			
+	// member
+	*(guint32*)&msg->message[position] = g_htonl(groupinfo->peers[0]);
+	position = position + sizeof(guint32);
+			
+	// member
+	*(guint32*)&msg->message[position] = g_htonl(groupinfo->peers[1]);
+	position = position + sizeof(guint32);
+			
+	// member
+	*(guint32*)&msg->message[position] = g_htonl(groupinfo->peers[2]);
+	
+	return msg;
+
+}
+
 gems_message* gems_create_message_collaboration_action_confirmed()
 {
 	gems_message* msg = (gems_message*)g_malloc(sizeof(gems_message));	
