@@ -257,6 +257,19 @@ guchar* gems_security_calculate_hash(guchar* data, guint* data_length)
 	guint hash_length = 0;
 	guchar* hash = NULL;
 	gchar* logmsg = NULL;
+	
+	if(data == NULL)
+	{
+		cem_add_to_log("gems_security_calculate_hash() : Cannot calculate hash, input data is NULL.",J_LOG_ERROR);
+		return NULL;
+	}
+	
+	if(*data_length == 0)
+	{
+		cem_add_to_log("gems_security_calculate_hash() : Cannot calculate hash, input data length is 0.",J_LOG_ERROR);
+		return NULL;
+	}
+	
 	gems_security_context* security = gems_get_security_contexts();
 	
 	if(security == NULL)
@@ -287,7 +300,7 @@ guchar* gems_security_calculate_hash(guchar* data, guint* data_length)
 		return NULL;
 	}
 	
-	EVP_DigestUpdate(security->digest,data,strlen((gchar*)data));
+	EVP_DigestUpdate(security->digest,data,*data_length);
 	EVP_DigestFinal_ex(security->digest,hash,&hash_length);
 	*data_length = hash_length;
 	
@@ -296,6 +309,7 @@ guchar* gems_security_calculate_hash(guchar* data, guint* data_length)
 
 gboolean gems_security_verify_hash(guchar* hash1, guchar* hash2)
 {
+	if(hash1 == NULL || hash2 == NULL) return FALSE;
 	return (g_strcmp0((gchar*)hash1,(gchar*)hash2) == 0) ? TRUE : FALSE;
 }
 
