@@ -67,6 +67,9 @@ gboolean gems_service_group_process_request(gems_connection* element)
 		case GROUP_IS_LOCKED:
 			gems_service_group_handle_locked(data, element);
 			break;
+		case FORCE_GROUP:
+			gems_service_group_handle_force_group(data, element);
+			break;
 		default:
 			break;
 	}
@@ -946,4 +949,22 @@ void gems_service_group_handle_locked(gems_components* data, gems_connection* el
 	}
 }
 
+void gems_service_group_handle_force_group(gems_components* data, gems_connection* element)
+{
+
+	//Only force group if we are not in one already(?)
+	if(data->service_group->group_info->id == NOT_ACTIVE)
+	{
+		data->service_group->group_info->id = gems_connection_get_32(element,8);
+		data->service_group->group_info->owner = gems_connection_get_32(element,12);
+		data->service_group->group_info->type = gems_connection_get_16(element,16);
+		data->service_group->group_info->size = gems_connection_get_16(element,18);
+		data->service_group->group_info->spaces = gems_connection_get_16(element,20);
+		data->service_group->group_info->theme = gems_connection_get_16(element,22);
+		data->service_group->group_info->peers[0] = gems_connection_get_32(element,26);
+		data->service_group->group_info->peers[1] = gems_connection_get_32(element,30);
+		data->service_group->group_info->peers[2] = gems_connection_get_32(element,34);
+	}
+}
+
 
