@@ -42,6 +42,7 @@ void gems_service_profile_cleanup_lists()
 gboolean gems_service_profile_process_request(gems_connection* element)
 {
 	gboolean success = TRUE;
+	gems_message* profilemsg = NULL;
 	gint16 command = gems_connection_get_16(element,(sizeof(gint16)+sizeof(gint32)));
 	gint position = 0;
 	gchar* logmsg = NULL;
@@ -52,26 +53,73 @@ gboolean gems_service_profile_process_request(gems_connection* element)
 		
 			if(gems_connection_get_16(element,(sizeof(gint16)+sizeof(gint32)+sizeof(gint16))) == GET_PROFILE_PUB)
 			{
-				gems_message* profilemsg = gems_create_message_service_profile(PROFILE_PUB);
+				profilemsg = gems_create_message_service_profile(PROFILE_PUB);
 				
 				if(profilemsg != NULL)
 				{					
 					// Send
 					if(gems_communication_write_encrypted_data(JAMMO_PACKET_PRIVATE,element,profilemsg) == FALSE)
+					{
 						logmsg = g_strdup_printf("gems_service_profile_process_request: cannot write PROFILE_PUB");
 						cem_add_to_log(logmsg,J_LOG_ERROR);
 						g_free(logmsg);
-					
+					}
 					// Free message
 					gems_clear_message(profilemsg);
 				}
 			}
+			else if(gems_connection_get_16(element,(sizeof(gint16)+sizeof(gint32)+sizeof(gint16))) == GET_PROFILE_FULL)
+			{
+				gems_teacher_connection* tc = gems_get_teacher_connection();
+	
+				// Connection to teacher exists
+				if(tc)
+				{
+					// Is connected
+					if(ph_c_connection_is_connected(tc->connection->connection) == TRUE)
+					{
+						// Message is coming from teacher
+						if(ph_c_connection_get_device_checksum(tc->connection->connection) == ph_c_connection_get_device_checksum(element->connection))
+						{
+							// TODO check that is authenticated as real teacher!
+							
+							profilemsg = gems_create_message_service_profile(PROFILE_FULL);
+							
+							if(profilemsg)
+							{
+								// Send
+								if(gems_communication_write_encrypted_data(JAMMO_PACKET_PRIVATE,element,profilemsg) == FALSE)
+									cem_add_to_log("gems_service_profile_process_request: cannot write PROFILE_FULL to teacher.",J_LOG_ERROR);
+					
+								// Free message
+								gems_clear_message(profilemsg);
+							}
+						}
+						else
+						{
+							cem_add_to_log("gems_service_profile_process_request: PROFILE_FULL request from other than teacher, ignored",J_LOG_NETWORK_DEBUG);
+							success = FALSE;
+						}
+					}
+					else
+					{
+						cem_add_to_log("gems_service_profile_process_request: PROFILE_FULL request received, no teacher connected, ignored",J_LOG_NETWORK_DEBUG);
+						success = FALSE;
+					}
+				}
+				else
+				{
+					cem_add_to_log("gems_service_profile_process_request: PROFILE_FULL request received, no teacher is set, ignored",J_LOG_NETWORK_DEBUG);
+					success = FALSE;
+				}
+				
+				success = TRUE;
+			}
 			else
 			{
-				logmsg = g_strdup_printf("gems_service_profile_process_request: requesting other than PROFILE_PUB");
+				logmsg = g_strdup_printf("gems_service_profile_process_request: requesting other than PROFILE_PUB/PROFILE_FULL");
 				cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 				g_free(logmsg);
-				//success = FALSE;
 			}
 			break;
 			
@@ -93,13 +141,13 @@ gboolean gems_service_profile_process_request(gems_connection* element)
 			position = position + sizeof(guint16);
 			
 			// avatar id
-			guint16 aid = gems_connection_get_16(element,position);
+			guint32 aid = gems_connection_get_32(element,position);
 			
 			// Already created?
 			if(element->profile == NULL) element->profile = gems_new_peer_profile(uname,uid,age,aid);
 			else gems_peer_profile_set_values(element->profile,uname,uid,age,aid);
 			
-			logmsg = g_strdup_printf("gems_service_profile_process_request: Got profile:\n\tId:\t%u\n\tName:\t%s\n\tAge:\t%d\n\tAvtr:\t%d",
+			logmsg = g_strdup_printf("gems_service_profile_process_request: Got profile:\n\tId:\t%u\n\tName:\t%s\n\tAge:\t%d\n\tAvtr:\t%u",
 				element->profile->id,element->profile->username,element->profile->age,element->profile->avatarid);
 			cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 			g_free(logmsg);
