@@ -732,7 +732,7 @@ gint gems_teacher_server_write_profile_database(teacher_server_profile_data* dat
 }
 
 // read the database from disk
-gint gems_teacher_server_read_profile_database(teacher_server_profile_data* data)
+gint gems_teacher_server_read_profile_database(teacher_server_profile_data** data)
 {
 	gchar* filename = g_build_filename(configure_get_jammo_directory(),TSRV_DATABASE,NULL);
 	gchar* contents = NULL;
@@ -753,26 +753,26 @@ gint gems_teacher_server_read_profile_database(teacher_server_profile_data* data
 		else
 		{
 			// Extract salt
-			if(data->salt != NULL) g_free(data->salt);
-			data->salt = (guchar*)g_malloc0(sizeof(guchar*) * AES_SALT_LENGTH);
-			*(guint32*)&data->salt[0] = *(guint32*)&contents[0];
-			*(guint32*)&data->salt[sizeof(guint32)] = *(guint32*)&contents[sizeof(guint32)];
+			if((*data)->salt != NULL) g_free((*data)->salt);
+			(*data)->salt = (guchar*)g_malloc0(sizeof(guchar*) * AES_SALT_LENGTH);
+			*(guint32*)&(*data)->salt[0] = *(guint32*)&contents[0];
+			*(guint32*)&(*data)->salt[sizeof(guint32)] = *(guint32*)&contents[sizeof(guint32)];
 			
 			// Extract password hash
-			if(data->pwhash != NULL) g_free(data->pwhash);
-			data->pwhash = (guchar*)g_malloc0(sizeof(guchar*) * (SHA_HASH_LENGTH + 1));
-			g_memmove(data->pwhash,&contents[AES_SALT_LENGTH],SHA_HASH_LENGTH);
+			if((*data)->pwhash != NULL) g_free((*data)->pwhash);
+			(*data)->pwhash = (guchar*)g_malloc0(sizeof(guchar*) * (SHA_HASH_LENGTH + 1));
+			g_memmove((*data)->pwhash,&contents[AES_SALT_LENGTH],SHA_HASH_LENGTH);
 			
 			// Extract profile hash
-			if(data->datahash != NULL) g_free(data->datahash);
-			data->datahash = (guchar*)g_malloc0(sizeof(guchar*) * (SHA_HASH_LENGTH + 1));
-			g_memmove(data->datahash,&contents[AES_SALT_LENGTH + SHA_HASH_LENGTH],SHA_HASH_LENGTH);
+			if((*data)->datahash != NULL) g_free((*data)->datahash);
+			(*data)->datahash = (guchar*)g_malloc0(sizeof(guchar*) * (SHA_HASH_LENGTH + 1));
+			g_memmove((*data)->datahash,&contents[AES_SALT_LENGTH + SHA_HASH_LENGTH],SHA_HASH_LENGTH);
 			
 			// Extract encrypted profile
-			if(data->data != NULL) g_free(data->data);
-			data->datalength = length - SHA_HASH_LENGTH - SHA_HASH_LENGTH - AES_SALT_LENGTH;
-			data->data = (guchar*)g_malloc0(sizeof(guchar*) * (data->datalength));
-			g_memmove(data->data,&contents[AES_SALT_LENGTH + SHA_HASH_LENGTH + SHA_HASH_LENGTH],data->datalength);
+			if((*data)->data != NULL) g_free((*data)->data);
+			(*data)->datalength = length - SHA_HASH_LENGTH - SHA_HASH_LENGTH - AES_SALT_LENGTH;
+			(*data)->data = (guchar*)g_malloc0(sizeof(guchar*) * ((*data)->datalength));
+			g_memmove((*data)->data,&contents[AES_SALT_LENGTH + SHA_HASH_LENGTH + SHA_HASH_LENGTH],(*data)->datalength);
 			
 			rval = READ_OK;
 		}
