@@ -183,7 +183,7 @@ static void gst_jammo_looper_class_init (GstJammoLooperClass * klass)
           G_PARAM_READWRITE | GST_PARAM_CONTROLLABLE | G_PARAM_STATIC_STRINGS));
   g_object_class_install_property (gobject_class, PROP_PITCH,
       g_param_spec_string ("pitch", "Pitch shift", "Pitch shift of produced sound",
-      		"D",
+          NULL,
           G_PARAM_READWRITE | GST_PARAM_CONTROLLABLE | G_PARAM_STATIC_STRINGS));
   gstbasesrc_class->set_caps = GST_DEBUG_FUNCPTR (gst_jammo_looper_setcaps);
   gstbasesrc_class->is_seekable =
