@@ -179,7 +179,7 @@ static void gst_jammo_sampler_class_init (GstJammoSamplerClass * klass)
           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
   g_object_class_install_property (gobject_class, PROP_INSTRUMENT_FOLDER,
       g_param_spec_string ("instrument-folder", "Virtual Instruments basefolder",
-          "instruments basefolder", "",
+          "instruments basefolder", NULL,
           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
   g_object_class_install_property(gobject_class, PROP_REMOVE_EVENT,
                                  g_param_spec_pointer ("remove-event",
