@@ -1,10 +1,11 @@
 
 #include "../../src/gems/gems_teacher_server_utils.h"
 #include "../../src/cem/cem.h"
+#include <stdio.h>
 
 teacher_server_profile_data* load(teacher_server_profile_data* data)
 {
-	switch(gems_teacher_server_read_profile_database(data))
+	switch(gems_teacher_server_read_profile_database(&data))
 	{
 		case READ_OK:
 			cem_add_to_log("Teacher database read success!",J_LOG_INFO);
@@ -16,9 +17,12 @@ teacher_server_profile_data* load(teacher_server_profile_data* data)
 			cem_add_to_log("Teacher database read failure!",J_LOG_INFO);
 			break;
 	}
-	
-	if(gems_teacher_server_decrypt_profiles(data,"mypassword")) cem_add_to_log("Teacher database decryption success!",J_LOG_INFO);
-	else cem_add_to_log("Teacher database decryption failure!",J_LOG_INFO);
+
+	if(data != NULL)
+	{
+		if(gems_teacher_server_decrypt_profiles(data,"mypassword")) cem_add_to_log("Teacher database decryption success!",J_LOG_INFO);
+		else cem_add_to_log("Teacher database decryption failure!",J_LOG_INFO);
+	}
 	
 	return data;
 }
@@ -98,8 +102,7 @@ int main(int argc, char* argv[])
 		
 		// load
 		data = load(data);
-		
-		if(g_list_length(data->profiles) != 0)
+		if((data) && (data->profiles) && (g_list_length(data->profiles) != 0))
 		{
 			cem_add_to_log("PROFILES IN LOADED DATABASE:",J_LOG_INFO);
 			gems_teacher_server_print_profile_list(data->profiles);
