@@ -317,7 +317,7 @@ void search_clients(serverdata* data)
 teacher_server_profile_data* load_database(teacher_server_profile_data* data)
 {
 	// Read profile db
-	switch(gems_teacher_server_read_profile_database(data))
+	switch(gems_teacher_server_read_profile_database(&data))
 	{
 		case READ_OK:
 			cem_add_to_log("Teacher database read success!",J_LOG_INFO);
